/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.crop.type;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.logging.Logger;
import nl.cloudfarming.client.crop.model.CropManager;
import nl.cloudfarming.client.crop.model.CropsStorage;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;
import org.openide.util.lookup.ServiceProvider;

/**
 * Implementing class for the CropManager
 * Will load and save Crop objects to and from the provided fileObject
 * @author Merijn Zengers
 */
@ServiceProvider(service = CropManager.class)
public class CropManagerImpl implements CropManager {

    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.crop.type");

    /**
     * Load a CropStorage object from a fileObject
     * @param fileObject the fileObject to load
     * @return CropStorage the found cropStorage
     */
    @Override
    public synchronized CropsStorage load(FileObject fileObject) {
        CropsStorage cropsStorage = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            cropsStorage = (CropsStorage) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return cropsStorage;
    }

    /**
     * Save a cropStorage object to file
     * @param cropsStorage the Object to save
     * @param fileObject the fileObject to save the CropsStorageObject to
     */
    @Override
    public synchronized void save(CropsStorage cropsStorage, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(cropsStorage);
        } catch (IOException ex) {
            LOG.fine(ex.toString());
        }
    }
}
